Usage
=====

.. warning::
  Discord really dislikes alternative clients such as slidcord (called "self bots"
  in their jargon), and you're breaking discord terms of use by using it. You
  might get your discord account suspended. Now you're warned. See
  :ref:`Keeping a low profile` for general tips about how to prevent this.

Roster
******

Contact JIDs are of the form ``123456@slidge-discord.example.org`` where ``123456`` is a
discord user ID.
